The package is the introduction of my online-self
=================================================

PyPi: https://pypi.org/project/Revalorise/

Hello! This package is the introduction of my online-self named
(Revalorise)

How to install
~~~~~~~~~~~~~~

open CMD / Terminal

.. code:: python

   pip install revalorise

How to use this package
~~~~~~~~~~~~~~~~~~~~~~~

-  open IDLE and type..

.. code:: python

   from revalorise import RevaloriseJr

   rev = revalorise() #Declare class name
   rev.show_name() #Show name
   rev.show_youtube() #Show youtube link
   rev.show_github() #Show Github link
   rev.about_me() #Show my bio
   rev.show_art() #Show ASCII Art

Developed by : Revalorise FB: https://www.facebook.com/

YouTube: https://www.youtube.com/ # The package is the introduction of
my online-self

PyPi: https://pypi.org/project/Revalorise/

Hello! This package is the introduction of my online-self named
(Revalorise)

.. _how-to-install-1:

How to install
~~~~~~~~~~~~~~

open CMD / Terminal

.. code:: python

   pip install revalorise

.. _how-to-use-this-package-1:

How to use this package
~~~~~~~~~~~~~~~~~~~~~~~

-  open IDLE and type..

.. code:: python

   from revalorise import RevaloriseJr

   rev = revalorise() #Declare class name
   rev.show_name() #Show name
   rev.show_youtube() #Show youtube link
   rev.show_github() #Show Github link
   rev.about_me() #Show my bio
   rev.show_art() #Show ASCII Art

Developed by : Revalorise FB: https://www.facebook.com/

YouTube: https://www.youtube.com/
